==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sk_SK.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Názov adresára kontaktov",
    "Import" : "Import",
    "The selected image is too big (max 1MB)" : "Vybraný obrázok je príliš veľký (max 1MB)",
    "No contacts in here" : "Nie sú tu žiadne kontakty",
    "Name" : "Názov",
    "Organization" : "Organizácia",
    "Title" : "Názov",
    "Add field ..." : "Pridať pole ...",
    "No search result for {query}" : "Žiadne výsledky vyhľadávania pre {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontaktov","%n kontaktov"],
    "Post office box" : "Poštová adresa",
    "Postal code" : "PSČ",
    "City" : "Mesto",
    "State or province" : "Štát alebo oblasť",
    "Country" : "Krajina",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "Last name" : "Priezvisko",
    "First name" : "Krstné meno",
    "Additional names" : "Ďalšie mená",
    "Prefix" : "Titul pred menom",
    "Suffix" : "Titul po mene",
    "All contacts" : "Všetky kontakty",
    "Not grouped" : "Bez skupiny",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} zdieľa {owner}",
    "No contacts in file. Only VCard files are allowed." : "Žiadne kontakty v súbore. Len VCard súbory sú povolené.",
    "Nickname" : "Prezývka",
    "Detailed name" : "Podrobné meno",
    "Notes" : "Poznámky",
    "Website" : "Webstránka",
    "Federated Cloud ID" : "Združené Cloud ID",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "Groups" : "Skupiny",
    "Birthday" : "Narodeniny",
    "Anniversary" : "Výročie",
    "Date of death" : "Dátum smrti",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefón",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax doma",
    "Fax work" : "Fax v práci",
    "Pager" : "Pager",
    "Voice" : "Odkazová schránka",
    "Social network" : "Sociálna sieť",
    "Settings" : "Nastavenia"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sk_SK.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "Delete" : "Zmazať",
    "can edit" : "môže upraviť",
    "Address book name" : "Názov adresára kontaktov",
    "Import" : "Import",
    "The selected image is too big (max 1MB)" : "Vybraný obrázok je príliš veľký (max 1MB)",
    "No contacts in here" : "Nie sú tu žiadne kontakty",
    "Name" : "Názov",
    "Organization" : "Organizácia",
    "Title" : "Názov",
    "Add field ..." : "Pridať pole ...",
    "No search result for {query}" : "Žiadne výsledky vyhľadávania pre {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontaktov","%n kontaktov"],
    "Post office box" : "Poštová adresa",
    "Postal code" : "PSČ",
    "City" : "Mesto",
    "State or province" : "Štát alebo oblasť",
    "Country" : "Krajina",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "Last name" : "Priezvisko",
    "First name" : "Krstné meno",
    "Additional names" : "Ďalšie mená",
    "Prefix" : "Titul pred menom",
    "Suffix" : "Titul po mene",
    "All contacts" : "Všetky kontakty",
    "Not grouped" : "Bez skupiny",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} zdieľa {owner}",
    "No contacts in file. Only VCard files are allowed." : "Žiadne kontakty v súbore. Len VCard súbory sú povolené.",
    "Nickname" : "Prezývka",
    "Detailed name" : "Podrobné meno",
    "Notes" : "Poznámky",
    "Website" : "Webstránka",
    "Federated Cloud ID" : "Združené Cloud ID",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "Groups" : "Skupiny",
    "Birthday" : "Narodeniny",
    "Anniversary" : "Výročie",
    "Date of death" : "Dátum smrti",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefón",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax doma",
    "Fax work" : "Fax v práci",
    "Pager" : "Pager",
    "Voice" : "Odkazová schránka",
    "Social network" : "Sociálna sieť",
    "Settings" : "Nastavenia"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
